@@ -3,23 +3,25 @@
     Provides root interface for working with Gatey.
 """
 
-import atexit
-from threading import Thread
-from time import sleep
 from typing import Callable, Union, Dict, List, Optional, Any
 
 # Utils.
 from gatey_sdk.utils import (
+    get_additional_event_tags,
+)
+from gatey_sdk.consts import DEFAULT_EVENTS_BUFFER_FLUSH_EVERY
+from gatey_sdk.internal.exc import (
     wrap_in_exception_handler,
     register_system_exception_hook,
     event_dict_from_exception,
-    get_additional_event_tags,
+    get_current_exception,
 )
 
 # Components.
 from gatey_sdk.api import Api
 from gatey_sdk.auth import Auth
-from gatey_sdk.transport import build_transport_instance, BaseTransport
+from gatey_sdk.transports import build_transport_instance, BaseTransport
+from gatey_sdk.buffer import EventsBuffer
 
 
 class _Client:
@@ -36,34 +38,18 @@ class _Client:
     """
 
     # Instances.
-    transport = None  # Used for sending instance (Passed with aggregation).
-    auth = None  # Used for authentication.
-    api = None  # Used for sending API HTTP requests.
-
-    # Events data queue that waiting for being sent to server.
-    _events_buffer: List[Dict[str, Any]] = []
-    _events_buffer_flush_thread: Optional[Thread] = None
+    transport: BaseTransport
+    auth: Auth
+    api: Api
+    events_buffer: EventsBuffer
 
     # Settings.
-
-    # If true, will send locals(), globals() variables,
-    # alongside with event data.
+    kwargs_settings: Dict[str, Any] = dict()
     exceptions_capture_vars = True
-
-    # If true, will capture source code lines for exception.
     exceptions_capture_code_context = True
-
-    # Buffering settings for bulk sending.
-    buffer_events_for_bulk_sending = None
-    buffer_events_max_capacity = 0
-    buffer_events_flush_every = 10.0
-
-    # Include event data.
     include_runtime_info = True
     include_platform_info = True
     include_sdk_info = True
-
-    # Default tags.
     default_tags_context = dict()
 
     def __init__(
@@ -74,7 +60,7 @@ class _Client:
         global_handler_skip_internal_exceptions: bool = True,
         buffer_events_for_bulk_sending: bool = False,
         buffer_events_max_capacity: int = 3,
-        buffer_events_flush_every: float = 10.0,
+        buffer_events_flush_every: float = DEFAULT_EVENTS_BUFFER_FLUSH_EVERY,
         handle_global_exceptions: bool = False,
         include_runtime_info: bool = True,
         include_platform_info: bool = True,
@@ -88,6 +74,8 @@ class _Client:
         server_secret: Optional[str] = None,
         client_secret: Optional[str] = None,
         check_api_auth_on_init: bool = True,
+        # Other params.
+        **kwargs_settings,
     ):
         """
         :param transport: BaseTransport layer for sending event to the server / whatever else.
@@ -114,24 +102,31 @@ class _Client:
             server_secret=server_secret,
             client_secret=client_secret,
         )
-        self.api = Api(auth=self.auth)
+        self.api = Api(
+            auth=self.auth,
+            http_request_kwargs=kwargs_settings.get("api_instance_kwargs", dict()),
+        )
         self.transport = build_transport_instance(
             transport_argument=transport, api=self.api, auth=self.auth
         )
+        self.events_buffer = EventsBuffer(
+            transport=self.transport,
+            skip_buffering=not buffer_events_for_bulk_sending,
+            max_capacity=buffer_events_max_capacity,
+            flush_every=buffer_events_flush_every,
+        )
 
         # Options.
         self.exceptions_capture_vars = exceptions_capture_vars
         self.exceptions_capture_code_context = exceptions_capture_code_context
-        self.buffer_events_for_bulk_sending = buffer_events_for_bulk_sending
-        self.buffer_events_max_capacity = buffer_events_max_capacity
-        self.buffer_events_flush_every = buffer_events_flush_every
         self.include_runtime_info = include_runtime_info
         self.include_platform_info = include_platform_info
         self.include_sdk_info = include_sdk_info
+        self.kwargs_settings = kwargs_settings.copy()
 
         # Tags like platform, sdk, etc.
         self.default_tags_context = self._build_default_tags_context(
-            foreign_tags=dict()
+            foreign_tags=kwargs_settings.get("default_tags_context", dict())
         )
 
         # Check API auth if requested and should.
@@ -141,17 +136,12 @@ class _Client:
             self.api.do_hard_auth_check()
 
         # Register system hooks.
-        self._bind_system_exit_hook()
         if handle_global_exceptions is True:
             register_system_exception_hook(
                 hook=self._on_catch_exception_hook,
                 skip_internal_exceptions=global_handler_skip_internal_exceptions,
             )
 
-        # Start flush thread for bulk sending after timeout (every N).
-        if self.buffer_events_for_bulk_sending:
-            self._ensure_running_buffer_flush_thread()
-
     def catch(
         self,
         *,
@@ -172,7 +162,7 @@ class _Client:
             exception=exception,
             ignored_exceptions=ignored_exceptions,
             skip_global_handler_on_ignore=skip_global_handler_on_ignore,
-            on_catch_exception=self.on_catch_exception_hook,
+            on_catch_exception=self._on_catch_exception_hook,
         )
 
     def capture_event(
@@ -209,7 +199,8 @@ class _Client:
         event_dict["level"] = level.lower()
 
         # Will buffer or immediatly send event.
-        return self._buffer_captured_event(event_dict=event_dict)
+        # return self._buffer_captured_event(event_dict=event_dict)
+        self.events_buffer.push_event(event_dict=event_dict)
 
     def capture_message(
         self,
@@ -236,7 +227,7 @@ class _Client:
 
     def capture_exception(
         self,
-        exception: BaseException,
+        exception: Optional[BaseException],
         *,
         level: str = "error",
         tags: Optional[Dict[str, str]] = None,
@@ -249,6 +240,16 @@ class _Client:
         :param tags: Dictionary of the tags (string-string).
         :param include_default_tags: If false, will force to not pass default tags context of the client to the event.
         """
+        if exception is None:
+            # If exception is not passed,
+            # get local current exception.
+            exception = get_current_exception()
+
+        if not isinstance(exception, BaseException):
+            raise TypeError(
+                "Expected `exception` to be an `BaseException`, please review your `capture_exception` call, or explicitly pass exception."
+            )
+
         exception_dict = event_dict_from_exception(
             exception=exception,
             skip_vars=not self.exceptions_capture_vars,
@@ -272,28 +273,6 @@ class _Client:
             raise TypeError("Tag name and value should be strings!")
         self.default_tags_context[tag_name] = tag_value
 
-    def bulk_send_buffered_events(self) -> bool:
-        """
-        Sends all buffered events.
-        Returns is all events was sent.
-        """
-
-        # Copy buffer and clear it.
-        events_bulk_queue = self._events_buffer.copy()
-        self._events_buffer = []
-
-        for event_dict in events_bulk_queue:
-            if not self.transport.send_event(event_dict=event_dict):
-                # If failed, pass back.
-                self._events_buffer.append(event_dict)
-        return len(self._events_buffer) == 0
-
-    def force_drop_buffered_events(self) -> None:
-        """
-        Drops (removes) buffered events explicitly.
-        """
-        self._events_buffer = []
-
     def _build_default_tags_context(
         self, foreign_tags: Dict[str, Any]
     ) -> Dict[str, Any]:
@@ -309,82 +288,25 @@ class _Client:
         default_tags.update(foreign_tags)
         return default_tags
 
-    def _ensure_running_buffer_flush_thread(self) -> Thread:
+    def bulk_send_buffered_events(self) -> bool:
         """
-        Runs buffer flush thread is it not running, and returns thread.
-        Flush thread is used to send events buffer after some time, not causing to wait core application
-        for terminate or new events that will trigger bulk sending (buffer flush).
+        Sends all buffered events.
+        Returns is all events was sent.
         """
+        return self.events_buffer.send_all()
 
-        if (
-            isinstance(self._events_buffer_flush_thread, Thread)
-            and self._events_buffer_flush_thread.is_alive()
-        ):
-            # If thread is currently alive - there is no need to create new thread by removing old reference.
-            return self._events_buffer_flush_thread
-
-        # Thread.
-        self._events_buffer_flush_thread = Thread(
-            target=self._buffer_flush_thread_target,
-            args=(),
-            name="sentry_sdk.events_buffer.flusher",
-        )
-
-        # Mark thread as daemon (which is required for graceful main thread termination) and start.
-        self._events_buffer_flush_thread.daemon = True
-        self._events_buffer_flush_thread.start()
-
-        return self._events_buffer_flush_thread
-
-    def _buffer_flush_thread_target(self) -> None:
+    def force_drop_buffered_events(self) -> None:
         """
-        Thread target for events buffer flusher.
+        Drops (removes) buffered events explicitly.
         """
-        while True:
-            sleep(self.buffer_events_flush_every)
-            self.bulk_send_buffered_events()
+        return self.events_buffer.clear_events()
 
-    def _on_catch_exception_hook(self, exception):
+    def _on_catch_exception_hook(self, exception) -> bool:
         """
         Hook that will be called when catched exception.
         (except via `capture_exception`)
         """
         return self.capture_exception(exception=exception)
 
-    def _bind_system_exit_hook(self) -> None:
-        """
-        Binds system hook for exit.
-        """
-
-        # Bulk send buffered events at exit.
-        if self.buffer_events_for_bulk_sending:
-            atexit.register(self.bulk_send_buffered_events)
-
-    def _events_buffer_is_full(self) -> bool:
-        """
-        Returns is events buffer is full and should be bulk sent.
-        """
-        if (
-            self.buffer_events_max_capacity is None
-            or self.buffer_events_max_capacity == 0
-        ):
-            return False
-        return len(self._events_buffer) >= self.buffer_events_max_capacity
-
-    def _buffer_captured_event(self, event_dict: Dict) -> bool:
-        """
-        Buffers captured event for bulk sending later.
-        """
-
-        # Pass directly if should not buffer.
-        if not self.buffer_events_for_bulk_sending:
-            return self.transport.send_event(event_dict=event_dict, __fail_fast=True)
-
-        # Do buffer and send if required.
-        self._events_buffer.append(event_dict)
-        if self._events_buffer_is_full():
-            return self.bulk_send_buffered_events()
-        return True
-
 
 Client = _Client
