@@ -27,6 +27,7 @@ class GateyStarletteMiddleware:
     capture_exception_options: Dict[str, Any] = {"include_default_tags": True}
     pre_capture_hook: HookCallable
     post_capture_hook: HookCallable
+    on_request_hook: HookCallable
     client_getter: ClientGetterCallable
     capture_reraise_after: bool = True
     capture_requests_info: bool = False
@@ -35,7 +36,7 @@ class GateyStarletteMiddleware:
     def __init__(
         self,
         app: ASGIApp,
-        client: Client | None = None,
+        client: Optional[Client] = None,
         *,
         capture_requests_info: bool = False,
         client_getter: Optional[ClientGetterCallable] = None,
@@ -113,21 +114,19 @@ class GateyStarletteMiddleware:
                 await self.pre_capture_hook(self, *app_args)
 
                 capture_options = self.capture_exception_options.copy()
-                if "tags" not in self.capture_exception_options:
+                if "tags" not in capture_options:
                     capture_options["tags"] = self._get_request_tags_from_scope(
                         scope=scope
                     )
 
-                client.capture_exception(
-                    _starlette_app_exception, **self.capture_options
-                )
+                client.capture_exception(_starlette_app_exception, **capture_options)
 
                 await self.post_capture_hook(self, *app_args)
 
             if self.capture_reraise_after:
                 raise _starlette_app_exception
 
-    async def _get_request_tags_from_scope(self, scope: Scope) -> Dict[str, str]:
+    def _get_request_tags_from_scope(self, scope: Scope) -> Dict[str, str]:
         """
         Returns tags for request from request scope.
         """
@@ -169,6 +168,7 @@ class GateyStarletteMiddleware:
         """
         return self.gatey_client
 
+    @staticmethod
     async def _default_void_hook(*_) -> None:
         """
         Default hook for pre/post capture, just does nohing.
